bitcoin_explorer.bitcoin_explorer API documentation

# bitcoin_explorer.bitcoin_explorer

class BitcoinDB:
BitcoinDB()
def get_block_full(self, height, /):
def get_block_simple(self, height, /):
def get_block_full_connected(self, height, /):
def get_block_simple_connected(self, height, /):
def get_block_header(self, height, /):
def get_hash_from_height(self, height, /):
def get_height_from_hash(self, hash, /):
def get_height_from_txid(self, txid, /):
def get_transaction_full(self, txid, /):
def get_transaction_simple(self, txid, /):
def get_transaction_full_connected(self, txid, /):
def get_transaction_simple_connected(self, txid, /):
def iter_block_full_arr(self, stop, /):
def iter_block_simple_arr(self, stop, /):
def iter_block_full_seq(self, start, stop, /):
def iter_block_simple_seq(self, start, stop, /):
def iter_block_full_connected(self, stop, /):
def iter_block_simple_connected(self, stop, /):
def get_max_height(self, /):
def parse_script(self, script_pub_key, /):